==> org.eclipse.team.core.source_3.8.100.v20170516-0820.jar: org/eclipse/team/internal/core/mapping/ResourceVariantFileRevision.java <==
/*******************************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.core.mapping;

import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.*;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileRevision;
import org.eclipse.team.core.variants.IResourceVariant;

public class ResourceVariantFileRevision extends FileRevision implements IAdaptable {
	private final IResourceVariant variant;

	public ResourceVariantFileRevision(IResourceVariant variant) {
		this.variant = variant;
	}

	public IStorage getStorage(IProgressMonitor monitor) throws CoreException {
		return variant.getStorage(monitor);
	}

	public String getName() {
		return variant.getName();
	}

	public String getContentIdentifier() {
		return variant.getContentIdentifier();
	}

	public IResourceVariant getVariant() {
		return variant;
	}

	public boolean isPropertyMissing() {
		return false;
	}

	public IFileRevision withAllProperties(IProgressMonitor monitor) throws CoreException {
		return this;
	}

	public Object getAdapter(Class adapter) {
		if (adapter == IResourceVariant.class)
			return variant;
		Object object = Platform.getAdapterManager().getAdapter(this, adapter);
		if (object != null)
			return object;
		if (variant instanceof IAdaptable ) {
			IAdaptable  adaptable = (IAdaptable ) variant;
			return adaptable.getAdapter(adapter);
		}
		return null;
	}

	public boolean equals(Object obj) {
		if (obj instanceof ResourceVariantFileRevision) {
			ResourceVariantFileRevision fileRevision = (ResourceVariantFileRevision) obj;
			return fileRevision.getVariant().equals(getVariant());
		}
		return false;
	}

	public int hashCode() {
		return getVariant().hashCode();
	}
}

==> org.eclipse.team.core.source_3.8.200.v20180309-1840.jar: org/eclipse/team/internal/core/mapping/ResourceVariantFileRevision.java <==
/*******************************************************************************
 * Copyright (c) 2006, 2017 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.core.mapping;

import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.*;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileRevision;
import org.eclipse.team.core.variants.IResourceVariant;

public class ResourceVariantFileRevision extends FileRevision implements IAdaptable {
	private final IResourceVariant variant;

	public ResourceVariantFileRevision(IResourceVariant variant) {
		this.variant = variant;
	}

	@Override
	public IStorage getStorage(IProgressMonitor monitor) throws CoreException {
		return variant.getStorage(monitor);
	}

	@Override
	public String getName() {
		return variant.getName();
	}

	@Override
	public String getContentIdentifier() {
		return variant.getContentIdentifier();
	}

	public IResourceVariant getVariant() {
		return variant;
	}

	@Override
	public boolean isPropertyMissing() {
		return false;
	}

	@Override
	public IFileRevision withAllProperties(IProgressMonitor monitor) throws CoreException {
		return this;
	}

	@Override
	@SuppressWarnings("unchecked")
	public <T> T getAdapter(Class<T> adapter) {
		if (adapter == IResourceVariant.class)
			return (T) variant;
		Object object = Platform.getAdapterManager().getAdapter(this, adapter);
		if (object != null)
			return (T) object;
		if (variant instanceof IAdaptable ) {
			IAdaptable  adaptable = (IAdaptable ) variant;
			return adaptable.getAdapter(adapter);
		}
		return null;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof ResourceVariantFileRevision) {
			ResourceVariantFileRevision fileRevision = (ResourceVariantFileRevision) obj;
			return fileRevision.getVariant().equals(getVariant());
		}
		return false;
	}

	@Override
	public int hashCode() {
		return getVariant().hashCode();
	}
}
